@@ -1,6 +1,6 @@
 /* acontainer.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2004-2005 Ralf Hoffmann.
+ * Copyright (C) 2004-2008 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -16,9 +16,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
-/* $Id: acontainer.cc,v 1.7 2005/05/15 13:44:10 ralf Exp $ */
 
 #include "acontainer.h"
 #include "awindow.h"
@@ -34,6 +33,7 @@ AContainer::AContElem::AContElem()
   AutosizeMode = ACONT_NONE;
   WWeight = HWeight = 1;
   NoResize = false;
+  m_center = false;
 }
 
 Widget *AContainer::AContElem::widelem() const
@@ -164,6 +164,16 @@ void AContainer::AContElem::noResize( bool nv )
   NoResize = nv;
 }
 
+bool AContainer::AContElem::center() const
+{
+    return m_center;
+}
+
+void AContainer::AContElem::center( bool nv )
+{
+    m_center = nv;
+}
+
 AContainer::AContainer( AWindow *twin, int txelems, int tyelems )
 {
   win = twin;
@@ -208,6 +218,7 @@ Widget *AContainer::add( Widget *newelement, int tx, int ty, int tautosizeMode )
   elements[tx + xelems * ty].widelem( newelement );
   elements[tx + xelems * ty].autosizeMode( tautosizeMode );
   elements[tx + xelems * ty].noResize( ( ( tautosizeMode & ACONT_NORESIZE ) != 0 ) ? true : false );
+  elements[tx + xelems * ty].center( ( ( tautosizeMode & ACONT_CENTER ) != 0 ) ? true : false );
   if ( win != NULL ) win->add( newelement );
   
   if ( ( tautosizeMode & ACONT_MINW ) != 0 ) {
@@ -636,6 +647,15 @@ int AContainer::rearrange( int vhmode )
 	  elements[ind].width( uw );
 	  elements[ind].height( uh );
 	  if ( elements[ind].widelem() != NULL ) {
+            if ( elements[ind].center() == true ) {
+              int tcx = ux + uw / 2;
+              int tcy = uy + uh / 2;
+              
+              tcx -= elements[ind].widelem()->getWidth() / 2;
+              tcy -= elements[ind].widelem()->getHeight() / 2;
+              if ( tcx > ux ) ux = tcx;
+              if ( tcy > uy ) uy = tcy;
+            }
 	    if ( vhmode == ACONT_ONLYH ) {
 	      uy = elements[ind].widelem()->getY();
 	      uh = elements[ind].widelem()->getHeight();
