@@ -1,6 +1,6 @@
 /* acontainer.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2004-2005 Ralf Hoffmann.
+ * Copyright (C) 2004-2007 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -16,9 +16,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
-/* $Id: acontainer.h,v 1.7 2005/12/05 06:38:41 ralf Exp $ */
 
 #ifndef ACONTAINER_H
 #define ACONTAINER_H
@@ -38,7 +37,8 @@ public:
 	 ACONT_MAXH = 2,
 	 ACONT_MINW = 4,
 	 ACONT_MINH = 8,
-	 ACONT_NORESIZE = 16 };
+	 ACONT_NORESIZE = 16,
+         ACONT_CENTER = 32 };
 
   static const int CINCW = ACONT_MINH + ACONT_MINW + ACONT_MAXH;
   static const int CINCWNR = CINCW + ACONT_NORESIZE;
@@ -122,6 +122,8 @@ public:
 
     int noResize() const;
     void noResize( bool nv );
+    bool center() const;
+    void center( bool nv );
   private:
     class Widget *_widelem;
     AContainer *Cont;
@@ -131,6 +133,7 @@ public:
     int AutosizeMode;
     int WWeight, HWeight;
     bool NoResize;
+    bool m_center;
   };
 
   AContElem *elements;
