@@ -1,6 +1,6 @@
 /* awindow.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2007 Ralf Hoffmann.
+ * Copyright (C) 2001-2008 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "awindow.h"
@@ -414,11 +414,14 @@ bool AWindow::isParent(Window childwin,bool direct) const
     for ( childs_const_it it1 = _childs.begin(); it1 != _childs.end(); it1++ ) {
       twin = dynamic_cast<AWindow*>( (*it1) );
       if ( twin != NULL ) {
-	if ( twin->isParent( childwin, false ) == true ) found = true;
+          if ( twin->isParent( childwin, false ) == true ) {
+              found = true;
+              break;
+          }
       }
     }
   }
-  if ( hasSubWin( childwin ) == true ) found = true;
+  if ( found == false && hasSubWin( childwin ) == true ) found = true;
   if ( childwin == win ) found = true;
   return found;
 }
@@ -1034,7 +1037,7 @@ void AWindow::doDestroyStuff()
     Display *dsp=_aguix->getDisplay();
     _aguix->removeWindow( this );
 
-#if WMDESTROYBUGFIX
+#ifdef WMDESTROYBUGFIX
     if ( _parent == NULL ) {
       _aguix->Flush();
       XSync( dsp, False );
@@ -1360,3 +1363,9 @@ bool AWindow::callBackForbidden() const
   if ( _parent != NULL ) return _parent->callBackForbidden();
   return false;
 }
+
+void AWindow::toFront()
+{
+    if ( _created == false ) return;
+    _aguix->WindowtoFront( win );
+}
