@@ -1,6 +1,6 @@
 /* awindow.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2006 Ralf Hoffmann.
+ * Copyright (C) 2001-2008 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -16,9 +16,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
-/* $Id: awindow.h,v 1.40 2005/12/01 21:13:29 ralf Exp $ */
 
 #ifndef AWINDOW_H
 #define AWINDOW_H
@@ -67,7 +66,7 @@ public:
   void toFront();
   void move( int nx, int ny );
   void resize( int nw, int nh );
-  void sizeChanged(int width,int height);
+  virtual void sizeChanged( int width, int height );
   void redraw();
   const char *getTitle() const;
   void setTitle( std::string new_title );
