@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "cyclebutton.h"
@@ -112,10 +112,10 @@ void CycleButton::setOption(int index2)
 
 void CycleButton::setFG(int tfg)
 {
-  if((tfg<(_aguix->getMaxCols()))&&(tfg>=0)) {
-    this->fg=tfg;
-  }
-  redraw();
+    if ( tfg < _aguix->getNumberOfColorsForType( AGUIXColor::USER_COLOR ) && tfg >= 0 ) {
+        this->fg = tfg;
+    }
+    redraw();
 }
 
 int CycleButton::getFG() const
@@ -125,10 +125,10 @@ int CycleButton::getFG() const
 
 void CycleButton::setBG(int tbg)
 {
-  if((tbg<(_aguix->getMaxCols()))&&(tbg>=0)) {
-    this->bg=tbg;
-  }
-  redraw();
+    if ( tbg < _aguix->getNumberOfColorsForType( AGUIXColor::USER_COLOR ) && tbg >= 0 ) {
+        this->bg = tbg;
+    }
+    redraw();
 }
 
 int CycleButton::getBG() const
