@@ -1,6 +1,6 @@
 /* fieldlistview.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2002-2006 Ralf Hoffmann.
+ * Copyright (C) 2002-2008 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "fieldlistview.h"
@@ -147,6 +147,8 @@ FieldListView::FieldListView( AGUIX *caguix, int cx, int cy, int cwidth, int che
   _last_single_select_time = 0;
   _last_single_middle_row = -1;
   _last_single_middle_time = 0;
+
+  m_complete_update = false;
 }
 
 FieldListView::~FieldListView()
@@ -274,7 +276,7 @@ void FieldListView::setFieldWidth( int field, int width )
  *
  * this will not redraw the lv because of the performance
  */
-void FieldListView::setText( int row, int field, std::string text )
+void FieldListView::setText( int row, int field, std::string text, bool update_simple_set )
 {
   Content *te;
   int tl;
@@ -304,6 +306,7 @@ void FieldListView::setText( int row, int field, std::string text )
         used_width[ field ] = tl;
 	maxrow[ field ] = row;
 	cond_changed = true;
+        m_complete_update = true;
       } else if ( tl < used_width[ field ] ) {
         // text is shorter
 	if ( ( maxrow[ field ] < 0 ) || ( maxrow[ field ] == row ) ) {
@@ -312,12 +315,19 @@ void FieldListView::setText( int row, int field, std::string text )
 	  used_width[ field ] = -1;
 	  maxrow[ field ] = -1;
 	  cond_changed = true;
+          m_complete_update = true;
 	}
       }
     }
   }
   elementarray[ row ]->setText( field, text );
-  if ( isRowVisible( row ) == true ) cond_changed = true;
+  if ( isRowVisible( row ) == true ) {
+      cond_changed = true;
+
+      if ( update_simple_set == true ) {
+          m_updated_rows.insert( row );
+      }
+  }
 }
 
 void FieldListView::increaseArray( int newsize )
@@ -1109,12 +1119,11 @@ void FieldListView::hbarredraw()
   _aguix->SetWindowBG( hbarwin, _parent->getBG() );
   _aguix->ClearWin( hbarwin );
   _aguix->drawBorder( hbarwin, ( hbar_dir == 1 ) ? true : false, tx, ty, th, th, 0 );
-  
-  if ( _aguix->extColorsAvail() == true ) {
-    _aguix->setFG( AGUIX::EXTCOLOR_DARKGRAY );
-    _aguix->FillRectangle( hbarwin, tx + th, ty,
-			   tw -  2 * th, th );
-  }
+
+  // dark grey
+  _aguix->setFG( AGUIXColor( 1, AGUIXColor::SYSTEM_COLOR ) );
+  _aguix->FillRectangle( hbarwin, tx + th, ty,
+                         tw -  2 * th, th );
 
   _aguix->setFG( 1 );
   _aguix->DrawLine( hbarwin, tx + th, ty + th - 1, tx + tw - th - 1, ty + th - 1 );
@@ -1199,11 +1208,10 @@ void FieldListView::vbarredraw()
 
   _aguix->drawBorder( vbarwin, ( vbar_dir == 1 ) ? true : false, tx, ty, tw, tw, 0 );
   
-  if ( _aguix->extColorsAvail() == true ) {
-    _aguix->setFG( AGUIX::EXTCOLOR_DARKGRAY );
-    _aguix->FillRectangle( vbarwin, tx, ty + tw,
-			   tw, th -  2 * tw );
-  }
+  // dark grey
+  _aguix->setFG( AGUIXColor( 1, AGUIXColor::SYSTEM_COLOR ) );
+  _aguix->FillRectangle( vbarwin, tx, ty + tw,
+                         tw, th -  2 * tw );
 
   _aguix->setFG(1);
   _aguix->DrawLine(vbarwin,tx+tw-1,ty+tw,tx+tw-1,ty+th-tw-1);
@@ -3735,3 +3743,20 @@ void FieldListView::handleEntryPressed( Message *msg )
         msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
     }
 }
+
+void FieldListView::simpleRedrawUpdatedRows()
+{
+    if ( m_complete_update == true ) {
+        m_complete_update = false;
+        m_updated_rows.clear();
+        cond_redraw();
+    } else {
+        for ( std::set<int>::const_iterator it1 = m_updated_rows.begin();
+              it1 != m_updated_rows.end();
+              it1++ ) {
+            redrawLine( *it1 );
+            drawBuffer( *it1 );
+        }
+        m_updated_rows.clear();
+    }
+}
