@@ -1,6 +1,6 @@
 /* fieldlistview.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2002-2006 Ralf Hoffmann.
+ * Copyright (C) 2002-2008 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -16,9 +16,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
-/* $Id: fieldlistview.h,v 1.33 2005/12/06 21:00:13 ralf Exp $ */
 
 #ifndef NEWLISTVIEW_H
 #define NEWLISTVIEW_H
@@ -31,6 +30,7 @@
 #include <stdio.h>
 #include <X11/Xlib.h>
 #include <X11/X.h>
+#include <set>
 
 class AGUIX;
 class AGUIXFont;
@@ -44,7 +44,7 @@ public:
   FieldListView &operator=( const FieldListView &other );
 
   void setNrOfFields( int nv );
-  void setText( int row, int field, std::string text );
+  void setText( int row, int field, std::string text, bool update_simple_set = false );
   std::string getText( int row, int field ) const;
   void trimElements();
   void setFieldWidth( int field, int width );
@@ -181,6 +181,8 @@ public:
   };
   void setColor( int row, const ColorDef &col );
   ColorDef getColor( int row ) const;
+
+  void simpleRedrawUpdatedRows();
 protected:
   int fields;
   int *fieldwidth;
@@ -354,6 +356,9 @@ protected:
   bool checkForValidButtonMod( unsigned int button,
                                unsigned int keystate,
                                unsigned int matching_mod );
+
+  std::set<int> m_updated_rows;
+  bool m_complete_update;
 };
 
 #endif
