@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 /* $Id: stringgadget.cc,v 1.54 2005/12/12 20:45:29 ralf Exp $ */
 
@@ -112,7 +112,6 @@ void StringGadget::setData(int tdata)
 
 void StringGadget::redraw()
 {
-  int maxcol=_aguix->getMaxCols();
   int newbg;
 
   if ( isCreated() == true ) {
@@ -120,7 +119,7 @@ void StringGadget::redraw()
 
     _aguix->ClearWin(win);
     if(active==true) {
-      if(maxcol>7) {
+      if ( _aguix->getNumberOfColorsForType( AGUIXColor::USER_COLOR ) > 7 ) {
 	newbg=7;
       } else {
 	newbg=0;
@@ -145,7 +144,6 @@ void StringGadget::redraw()
 
 void StringGadget::textRedraw()
 {
-  int maxcol=_aguix->getMaxCols();
   int minx, maxx;
   int bw = getBorderWidth();
   int inner_x, inner_y;
@@ -260,7 +258,7 @@ void StringGadget::textRedraw()
 	_aguix->FillRectangle( win, inner_x + dx, inner_y + dy, strwidth, ch );
       }
       if(active==true) {
-	if(maxcol>7) {
+        if ( _aguix->getNumberOfColorsForType( AGUIXColor::USER_COLOR ) > 7 ) {
 	  text_color = 7;
 	} else {
 	  text_color = 0;
@@ -981,11 +979,10 @@ int StringGadget::clearTextBG()
   if ( isCreated() == false ) return 1;
 
   int bw = getBorderWidth();
-  int maxcol=_aguix->getMaxCols();
   int newbg;
   
   if ( active == true ) {
-    if(maxcol>7) {
+    if ( _aguix->getNumberOfColorsForType( AGUIXColor::USER_COLOR ) > 7 ) {
       newbg=7;
     } else {
       newbg=0;
