@@ -1,6 +1,6 @@
 /* textstorage.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2005 Ralf Hoffmann.
+ * Copyright (C) 2005-2008 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -15,10 +15,9 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not^, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
-/* $Id: textstorage.h,v 1.3 2005/08/16 21:01:32 ralf Exp $ */
 
 #ifndef TEXTSTORAGE_H
 #define TEXTSTORAGE_H
@@ -28,6 +27,7 @@
 #include <string>
 #include <utility>
 #include "awidth.h"
+#include "refcount.hh"
 
 class TextStorage
 {
@@ -39,18 +39,27 @@ class TextStorage
   virtual int getMaxLineWidth() const = 0;
   virtual int getLineWidth( int line_nr ) const = 0;
   virtual void setLineLimit( int new_limit ) = 0;
+  virtual int getLineLimit() = 0;
   virtual std::pair<int,int> getRealLinePair( int line_nr ) const = 0;
   virtual int findLineNr( std::pair<int,int> real_line ) const = 0;
   virtual AWidth &getAWidth() = 0;
+
+  virtual int getNrOfUnwrappedLines() const = 0;
+  virtual int getUnwrappedLine( int line_nr,
+                                unsigned int offset,
+                                int len,
+                                std::string &return_line ) const = 0;
+  virtual int getUnwrappedLine( int line_nr,
+                                unsigned int offset,
+                                std::string &return_line ) const = 0;
+  virtual std::pair< std::pair< int, int >, int > getLineForOffset( int unwrapped_line_nr, int line_offset ) const = 0;
 };
 
 class TextStorageString : public TextStorage
 {
  public:
-  TextStorageString( std::string content, AWidth &lencalc );
-  TextStorageString( const char *buf, int len, AWidth &lencalc );
-  TextStorageString( const TextStorageString &other );
-  TextStorageString &operator=( const TextStorageString &other );
+  TextStorageString( const std::string &content, const RefCount<AWidth> &lencalc, int line_limit = -1 );
+  TextStorageString( const char *buf, int len, const RefCount<AWidth> &lencalc, int line_limit = -1 );
 
   int getNrOfLines() const;
   int getLine( int line_nr, unsigned int offset, int len, std::string &return_line ) const;
@@ -58,11 +67,22 @@ class TextStorageString : public TextStorage
   int getMaxLineWidth() const;
   int getLineWidth( int line_nr ) const;
   void setLineLimit( int new_limit );
+  int getLineLimit();
   std::pair<int,int> getRealLinePair( int line_nr ) const;
   int findLineNr( std::pair<int,int> real_line ) const;
   AWidth &getAWidth();
+
+  int getNrOfUnwrappedLines() const;
+  int getUnwrappedLine( int line_nr,
+                        unsigned int offset,
+                        int len,
+                        std::string &return_line ) const;
+  int getUnwrappedLine( int line_nr,
+                        unsigned int offset,
+                        std::string &return_line ) const;
+  std::pair< std::pair< int, int >, int > getLineForOffset( int unwrapped_line_nr, int line_offset ) const;
  private:
-  void initBuffer( std::string &content, int line_limit_width = -1 );
+  void initBuffer( const std::string &content, int line_limit_width = -1 );
   unsigned int getTokenLen( unsigned int start_offset );
   
   std::string buffer;                      // stores text file
@@ -70,7 +90,13 @@ class TextStorageString : public TextStorage
                                            // for last line)
   std::vector<std::pair<int,int> > _real_lines;
   int getLineCharacters( int line_nr ) const;
-  AWidth &_lencalc;
+  RefCount<AWidth> m_lencalc;
+
+  /* stores offset for each real line (can be outside of buffer
+   * for last line) (no wrapping!)
+   */
+  std::vector<unsigned int> m_unwrapped_line_offsets;
+  int getUnwrappedLineCharacters( int line_nr ) const;
 
   //TODO better remove const modifier from getLineWidth and co?
   //     instead of declaring the cache mutable?
