@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #ifndef UTIL_H
@@ -30,6 +30,12 @@ int createLines(const char*,char ***);
 namespace AGUIXUtils
 {
     std::string bytes_to_human_readable( loff_t number );
+
+    std::string tolower( const std::string &str );
+    
+    bool stringIsShorter( const char *str, int len );
+
+    std::string formatStringToString( const char *format, ... );
 }
 
 #endif
