@@ -318,27 +318,33 @@
      SHOWPREVRESULTS_WCP = 544,
      TEXTVIEW_WCP = 545,
      TEXTVIEWHIGHLIGHTED_WCP = 546,
-     DIRBOOKMARKOP_WCP = 547,
-     OPENCONTEXTMENUOP_WCP = 548,
-     RUNCUSTOMACTION_WCP = 549,
-     CUSTOMNAME_WCP = 550,
-     CONTEXTBUTTON_WCP = 551,
-     ACTIVATEMOD_WCP = 552,
-     SCROLLMOD_WCP = 553,
-     CONTEXTMOD_WCP = 554,
-     NONE_WCP = 555,
-     CUSTOMACTION_WCP = 556,
-     ERROR = 557,
-     ACTIVESIDE_WCP = 558,
-     SHOWFREESPACE_WCP = 559,
-     ACTIVEMODE_WCP = 560,
-     ASK_WCP = 561,
-     SSHALLOW_WCP = 562,
-     FIELD_WIDTH_WCP = 563,
-     QUICKSEARCHENABLED_WCP = 564,
-     FILTEREDSEARCHENABLED_WCP = 565,
-     STRING_WCP = 566,
-     NUM_WCP = 567
+     TEXTVIEWSELECTION_WCP = 547,
+     DIRBOOKMARKOP_WCP = 548,
+     OPENCONTEXTMENUOP_WCP = 549,
+     RUNCUSTOMACTION_WCP = 550,
+     CUSTOMNAME_WCP = 551,
+     CONTEXTBUTTON_WCP = 552,
+     ACTIVATEMOD_WCP = 553,
+     SCROLLMOD_WCP = 554,
+     CONTEXTMOD_WCP = 555,
+     NONE_WCP = 556,
+     CUSTOMACTION_WCP = 557,
+     SAVE_WORKER_STATE_ON_EXIT_WCP = 558,
+     OPENWORKERMENUOP_WCP = 559,
+     ERROR = 560,
+     ACTIVESIDE_WCP = 561,
+     SHOWFREESPACE_WCP = 562,
+     ACTIVEMODE_WCP = 563,
+     ASK_WCP = 564,
+     SSHALLOW_WCP = 565,
+     FIELD_WIDTH_WCP = 566,
+     QUICKSEARCHENABLED_WCP = 567,
+     FILTEREDSEARCHENABLED_WCP = 568,
+     XFTFONTS_WCP = 569,
+     USEMAGIC_WCP = 570,
+     MAGICPATTERN_WCP = 571,
+     STRING_WCP = 572,
+     NUM_WCP = 573
    };
 #endif
 /* Tokens.  */
@@ -631,39 +637,45 @@
 #define SHOWPREVRESULTS_WCP 544
 #define TEXTVIEW_WCP 545
 #define TEXTVIEWHIGHLIGHTED_WCP 546
-#define DIRBOOKMARKOP_WCP 547
-#define OPENCONTEXTMENUOP_WCP 548
-#define RUNCUSTOMACTION_WCP 549
-#define CUSTOMNAME_WCP 550
-#define CONTEXTBUTTON_WCP 551
-#define ACTIVATEMOD_WCP 552
-#define SCROLLMOD_WCP 553
-#define CONTEXTMOD_WCP 554
-#define NONE_WCP 555
-#define CUSTOMACTION_WCP 556
-#define ERROR 557
-#define ACTIVESIDE_WCP 558
-#define SHOWFREESPACE_WCP 559
-#define ACTIVEMODE_WCP 560
-#define ASK_WCP 561
-#define SSHALLOW_WCP 562
-#define FIELD_WIDTH_WCP 563
-#define QUICKSEARCHENABLED_WCP 564
-#define FILTEREDSEARCHENABLED_WCP 565
-#define STRING_WCP 566
-#define NUM_WCP 567
+#define TEXTVIEWSELECTION_WCP 547
+#define DIRBOOKMARKOP_WCP 548
+#define OPENCONTEXTMENUOP_WCP 549
+#define RUNCUSTOMACTION_WCP 550
+#define CUSTOMNAME_WCP 551
+#define CONTEXTBUTTON_WCP 552
+#define ACTIVATEMOD_WCP 553
+#define SCROLLMOD_WCP 554
+#define CONTEXTMOD_WCP 555
+#define NONE_WCP 556
+#define CUSTOMACTION_WCP 557
+#define SAVE_WORKER_STATE_ON_EXIT_WCP 558
+#define OPENWORKERMENUOP_WCP 559
+#define ERROR 560
+#define ACTIVESIDE_WCP 561
+#define SHOWFREESPACE_WCP 562
+#define ACTIVEMODE_WCP 563
+#define ASK_WCP 564
+#define SSHALLOW_WCP 565
+#define FIELD_WIDTH_WCP 566
+#define QUICKSEARCHENABLED_WCP 567
+#define FILTEREDSEARCHENABLED_WCP 568
+#define XFTFONTS_WCP 569
+#define USEMAGIC_WCP 570
+#define MAGICPATTERN_WCP 571
+#define STRING_WCP 572
+#define NUM_WCP 573
 
 
 
 
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-#line 196 "configparser.y"
+#line 204 "configparser.y"
 typedef union YYSTYPE {
   int num;
   char *strptr;
 } YYSTYPE;
 /* Line 1447 of yacc.c.  */
-#line 667 "configparser.tab.h"
+#line 679 "configparser.tab.h"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
