@@ -1,6 +1,6 @@
 /* configtokens.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2003-2007 Ralf Hoffmann.
+ * Copyright (C) 2003-2008 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "wdefines.h"
@@ -319,6 +319,7 @@ struct mytoken tokenlist[]={
   { SHOWPREVRESULTS_WCP, "showprevresults" },
   { TEXTVIEW_WCP, "textview" },
   { TEXTVIEWHIGHLIGHTED_WCP, "textviewhighlighted" },
+  { TEXTVIEWSELECTION_WCP, "textviewselection" },
   { FILTEREDSEARCHENABLED_WCP, "filteredsearchenabled"},
   { DIRBOOKMARKOP_WCP, "dirbookmarkop" },
   { OPENCONTEXTMENUOP_WCP, "opencontextmenuop" },
@@ -329,7 +330,12 @@ struct mytoken tokenlist[]={
   { NONE_WCP, "none" },
   { RUNCUSTOMACTION_WCP, "runcustomaction" },
   { CUSTOMNAME_WCP, "customname" },
-  { CUSTOMACTION_WCP, "customaction" }
+  { CUSTOMACTION_WCP, "customaction" },
+  { SAVE_WORKER_STATE_ON_EXIT_WCP, "saveworkerstateonexit" },
+  { OPENWORKERMENUOP_WCP, "openworkermenuop" },
+  { XFTFONTS_WCP, "xftfonts" },
+  { USEMAGIC_WCP, "usemagic" },
+  { MAGICPATTERN_WCP, "magicpattern" }
 };
 
 ArrayList *tokenlist_sorted = NULL;
