@@ -1,6 +1,6 @@
 /* fileentry.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2007 Ralf Hoffmann.
+ * Copyright (C) 2001-2008 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "fileentry.hh"
@@ -28,6 +28,7 @@
 #include "condparser.h"
 #include "stringbuf.h"
 #include "wcfiletype.hh"
+#include "magic_db.hh"
 
 #ifndef MAXPATHLEN
 #define MAXPATHLEN 2048
@@ -235,7 +236,10 @@ void FileEntry::setLVC( FieldListView *lv, int row, const std::vector<WorkerType
           else s1 += ' ';
         }
 	s1 += name;
-        lv->setText( row, cur_field, s1 );
+        
+        // I only set update_set for name to avoid the overhead for
+        // every field as the name is probably always visible
+        lv->setText( row, cur_field, s1, true );
         break;
       case WorkerTypes::LISTCOL_SIZE:
         if ( S_ISCHR( statbuf.mode ) ||
@@ -478,7 +482,8 @@ FileEntry::typecandidate_t FileEntry::runTests( WCFiletype *type,
 						bool skipcontent,
 						CondParser *condparser,
 						unsigned char fbuffer[64],
-						int reads )
+						int reads,
+                                                typecheck_temp_results_t &temp_results )
 {
   typecandidate_t erg;
   int minsize, x, y;
@@ -515,6 +520,23 @@ FileEntry::typecandidate_t FileEntry::runTests( WCFiletype *type,
 	  }
 	}
       }
+
+      if ( erg.type == NULL && type->getUseMagic() == true ) {
+          erg.tests_done++;
+          if ( temp_results.magic_avail == false ) {
+              if ( worker_islocal( fullname ) == true ) {
+                  temp_results.magic_result = MagicDB::getInstance().getInfo( fullname );
+              } else {
+                  temp_results.magic_result = MagicDB::getInstance().getInfo( fbuffer, reads );
+              }
+              temp_results.magic_avail = true;
+          }
+
+          if ( type->magicMatch( temp_results.magic_result ) == true ) {
+              erg.prio = 3;
+              erg.type = type;
+          }
+      }
     }
   }
 
@@ -556,7 +578,8 @@ FileEntry::typecandidate_t FileEntry::checkFiletype( const std::list<WCFiletype*
 						     bool skipcontent,
 						     CondParser *condparser,
 						     unsigned char fbuffer[64],
-						     int reads )
+						     int reads,
+                                                     typecheck_temp_results_t &temp_results )
 {
   WCFiletype *ft;
   typecandidate_t cand1, erg, cand2;
@@ -577,13 +600,13 @@ FileEntry::typecandidate_t FileEntry::checkFiletype( const std::list<WCFiletype*
   
   for ( it1 = ftlist->begin(); it1 != ftlist->end(); it1++ ) {
     ft = *it1;
-    cand1 = runTests( ft, skipcontent, condparser, fbuffer, reads );
+    cand1 = runTests( ft, skipcontent, condparser, fbuffer, reads, temp_results );
     if ( ( cand1.type != NULL ) || ( cand1.tests_done < 1 ) ) {
       // check subtypes if we had a hit or did no tests
       subtypes = ft->getSubTypeList();
       if ( subtypes != NULL ) {
 	if ( subtypes->size() > 0 ) {
-	  cand2 = checkFiletype( subtypes, skipcontent, condparser, fbuffer, reads );
+            cand2 = checkFiletype( subtypes, skipcontent, condparser, fbuffer, reads, temp_results );
 	  if ( cand2.prio > 0 ) {
 	    // subtypes are always more important
 	    cand1.prio = cand2.prio;
@@ -613,6 +636,7 @@ WCFiletype* FileEntry::checkFiletype( List *ftlist, bool skipcontent, CondParser
   PDatei *pfp;
   typecandidate_t cand1, erg, cand2;
   const std::list<WCFiletype*> *subtypes;
+  typecheck_temp_results_t temp_results;
 
   if ( ftlist == NULL ) return NULL;
   
@@ -663,13 +687,13 @@ WCFiletype* FileEntry::checkFiletype( List *ftlist, bool skipcontent, CondParser
   id = ftlist->initEnum();
   ft = (WCFiletype*)ftlist->getFirstElement( id );
   while ( ft != NULL ) {
-    cand1 = runTests( ft, skipcontent, condparser, fbuffer, reads );
+      cand1 = runTests( ft, skipcontent, condparser, fbuffer, reads, temp_results );
     if ( ( cand1.type != NULL ) || ( cand1.tests_done < 1 ) ) {
       // check subtypes if we had a hit or did no tests
       subtypes = ft->getSubTypeList();
       if ( subtypes != NULL ) {
 	if ( subtypes->size() > 0 ) {
-	  cand2 = checkFiletype( subtypes, skipcontent, condparser, fbuffer, reads );
+            cand2 = checkFiletype( subtypes, skipcontent, condparser, fbuffer, reads, temp_results );
 	  if ( cand2.prio > 0 ) {
 	    // subtypes are always more important
 	    cand1.prio = cand2.prio;
