@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "nmextlist.hh"
@@ -163,7 +163,7 @@ int NMExtList::create_externfe_rec( const char *fullname, bool rec, const FileEn
         for ( Verzeichnis::verz_it tfe_it1 = tverz->begin();
               tfe_it1 != tverz->end();
               tfe_it1++ ) {
-            FileEntry *tfe = tfe = *tfe_it1;
+            FileEntry *tfe = *tfe_it1;
             if ( strcmp( tfe->name, ".." ) != 0 ) {
                 create_externfe_rec( tfe->fullname, rec, NULL );
             }
