@@ -1,6 +1,6 @@
 /* searchop.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2006-2007 Ralf Hoffmann.
+ * Copyright (C) 2006-2008 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "searchop.hh"
@@ -30,6 +30,7 @@
 #include "flagreplacer.hh"
 #include <aguix/acontainerbb.h>
 #include <typeinfo>
+#include "filenameshrinker.hh"
 
 const char *SearchOp::name = "SearchOp";
 std::list<SearchOp::ResultStore*> SearchOp::_stored_results;
@@ -56,6 +57,7 @@ SearchOp::SearchOp() : FunctionProto(),
                        _matchcontent_case_cb( NULL ),
                        _follow_symlinks_cb( NULL ),
                        _search_vfs_cb( NULL ),
+                       _search_same_fs_cb( NULL ),
                        _search_started( false )
 {
   _edit_command = DEFAULT_EDIT_COMMAND;
@@ -183,7 +185,7 @@ SearchOp::run( WPUContext *wpu, ActionMessage *msg )
   _matchcontent_case_cb->resize( _matchcontent_sg->getHeight(), _matchcontent_sg->getHeight() );
   ac1_3->readLimits();
 
-  AContainer *ac1_globsets = ac1_1->add( new AContainer( win, 4, 1 ), 0, 1 );
+  AContainer *ac1_globsets = ac1_1->add( new AContainer( win, 5, 1 ), 0, 1 );
   ac1_globsets->setMinSpace( 5 );
   ac1_globsets->setMaxSpace( 5 );
   ac1_globsets->setBorderWidth( 0 );
@@ -192,13 +194,15 @@ SearchOp::run( WPUContext *wpu, ActionMessage *msg )
                                                                             catalog.getLocale( 298 ), LABEL_RIGHT, 1, 0 ), 0, 0, AContainer::CFIXNR );
   _search_vfs_cb = (ChooseButton*)ac1_globsets->add( new ChooseButton( aguix, 0, 0, false,
                                                                        catalog.getLocale( 727 ), LABEL_RIGHT, 1, 0 ), 1, 0, AContainer::CFIXNR );
+  _search_same_fs_cb = (ChooseButton*)ac1_globsets->add( new ChooseButton( aguix, 0, 0, false,
+                                                                           catalog.getLocale( 792 ), LABEL_RIGHT, 1, 0 ), 2, 0, AContainer::CFIXNR );
   Button *newsearchb = (Button*)ac1_globsets->add( new Button( aguix,
                                                                0,
                                                                0,
                                                                catalog.getLocale( 728 ),
                                                                1,
                                                                0,
-                                                               0 ), 3, 0, AContainer::CFIX );
+                                                               0 ), 4, 0, AContainer::CFIX );
 
   AContainer *ac1_res = ac1->add( new AContainer( win, 1, 2 ), 0, 1 );
   ac1_res->setMinSpace( 5 );
@@ -268,6 +272,7 @@ SearchOp::run( WPUContext *wpu, ActionMessage *msg )
 
   ac1_6->add( new Text( aguix, 0, 0, catalog.getLocale( 739 ), 1 ), 0, 0, AContainer::CFIX );
   Text *state_text = (Text*)ac1_6->add( new Text( aguix, 0, 0, catalog.getLocale( 740 ), 1 ), 1, 0, AContainer::CINCW );
+  state_text->setTextShrinker( RefCount<TextShrinker>( new FileNameShrinker() ) );
 
   AContainer *ac1_5 = ac1->add( new AContainer( win, 4, 1 ), 0, 4 );
   ac1_5->setMinSpace( 5 );
@@ -743,8 +748,9 @@ SearchOp::ResultStore *SearchOp::getResultStore( int pos, const SearchSettings *
 class DW_SetFollowSymlinks : public NWC::DirWalkCallBack
 {
 public:
-  DW_SetFollowSymlinks( bool follow_symlinks, bool search_vfs ) : _follow_symlinks( follow_symlinks ),
-                                                                  _search_vfs( search_vfs ) {}
+    DW_SetFollowSymlinks( bool follow_symlinks, bool search_vfs, bool search_same_fs ) : _follow_symlinks( follow_symlinks ),
+                                                                                         _search_vfs( search_vfs ),
+                                                                                         _search_same_fs( search_same_fs ) {}
 
   int visit( NWC::File &file, NWC::Dir::WalkControlObj &cobj ) { return 0; }
   int visitEnterDir( NWC::Dir &dir, NWC::Dir::WalkControlObj &cobj )
@@ -754,6 +760,7 @@ public:
     try {
       NWC::VirtualDir &vdir = dynamic_cast<NWC::VirtualDir&>( dir );
       vdir.setSearchVFS( _search_vfs );
+      vdir.setSearchSameFS( _search_same_fs );
     } catch ( std::bad_cast ) {
     }
     return 0;
@@ -762,6 +769,7 @@ public:
 private:
   bool _follow_symlinks;
   bool _search_vfs;
+  bool _search_same_fs;
 };
 
 void SearchOp::startSearch()
@@ -785,8 +793,9 @@ void SearchOp::startSearch()
   
   use_dir->setFollowSymlinks( sets.getFollowSymlinks() );
   use_dir->setSearchVFS( sets.getSearchVFS() );
+  use_dir->setSearchSameFS( sets.getSearchSameFS() );
   
-  DW_SetFollowSymlinks dw1( sets.getFollowSymlinks(), sets.getSearchVFS() );
+  DW_SetFollowSymlinks dw1( sets.getFollowSymlinks(), sets.getSearchVFS(), sets.getSearchSameFS() );
   use_dir->walk( dw1 );
 
   _sth = new SearchThread( std::auto_ptr<NWC::Dir>( use_dir ) );
@@ -876,7 +885,8 @@ SearchOp::SearchSettings SearchOp::getCurrentSearchSettings()
                        _matchcontent_sg->getText(),
                        _matchcontent_case_cb->getState(),
                        _follow_symlinks_cb->getState(),
-                       _search_vfs_cb->getState() );
+                       _search_vfs_cb->getState(),
+                       _search_same_fs_cb->getState() );
   return sets;
 }
 
@@ -903,6 +913,7 @@ void SearchOp::restoreSearchSettings()
   _matchcontent_case_cb->setState( sets.getMatchContentCase() );
   _follow_symlinks_cb->setState( sets.getFollowSymlinks() );
   _search_vfs_cb->setState( sets.getSearchVFS() );
+  _search_same_fs_cb->setState( sets.getSearchSameFS() );
 }
 
 void SearchOp::setCurrentResultStore( int pos, const SearchSettings *sets )
@@ -937,6 +948,7 @@ void SearchOp::cleanupPtrs()
   _matchcontent_case_cb = NULL;
   _follow_symlinks_cb = NULL;
   _search_vfs_cb = NULL;
+  _search_same_fs_cb = NULL;
 }
 
 void SearchOp::removeSelectedResults()
