@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "searchop.hh"
@@ -30,7 +30,8 @@ SearchOp::SearchSettings::SearchSettings() : _basedir( "" ),
                                              _matchcontent_case( false ),
                                              _active_row( -1 ),
                                              _follow_symlinks( false ),
-                                             _search_vfs( false )
+                                             _search_vfs( false ),
+                                             _search_same_fs( false )
 {
 }
 
@@ -42,16 +43,18 @@ SearchOp::SearchSettings::SearchSettings( const std::string &basedir,
                                           const std::string &matchcontent,
                                           bool matchcontent_case,
                                           bool follow_symlinks,
-                                          bool search_vfs ) : _basedir( basedir ),
-                                                              _matchname( matchname ),
-                                                              _matchname_re( matchname_re ),
-                                                              _matchname_fullpath( matchname_fullpath ),
-                                                              _matchname_case( matchname_case ),
-                                                              _matchcontent( matchcontent ),
-                                                              _matchcontent_case( matchcontent_case ),
-                                                              _active_row( -1 ),
-                                                              _follow_symlinks( follow_symlinks ),
-                                                              _search_vfs( search_vfs )
+                                          bool search_vfs,
+                                          bool search_same_fs ) : _basedir( basedir ),
+                                                                  _matchname( matchname ),
+                                                                  _matchname_re( matchname_re ),
+                                                                  _matchname_fullpath( matchname_fullpath ),
+                                                                  _matchname_case( matchname_case ),
+                                                                  _matchcontent( matchcontent ),
+                                                                  _matchcontent_case( matchcontent_case ),
+                                                                  _active_row( -1 ),
+                                                                  _follow_symlinks( follow_symlinks ),
+                                                                  _search_vfs( search_vfs ),
+                                                                  _search_same_fs( search_same_fs )
 {
 }
 
@@ -113,3 +116,8 @@ bool SearchOp::SearchSettings::getSearchVFS() const
 {
   return _search_vfs;
 }
+
+bool SearchOp::SearchSettings::getSearchSameFS() const
+{
+  return _search_same_fs;
+}
