@@ -1,6 +1,6 @@
 /* startprogop.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2007 Ralf Hoffmann.
+ * Copyright (C) 2001-2008 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "startprogop.h"
@@ -813,8 +813,8 @@ std::auto_ptr< StartProgOp::StartSettings > StartProgOp::showGUI()
 
       row = ftw->_lv->getActiveRow();
       if ( ( ftw->_lv->isValidRow( row ) == true ) &&
-	   ( row < (int)ftw->_flatlist->size() ) ) {
-	WCFiletype *ft = (*ftw->_flatlist)[row].filetype;
+	   ( row < ftw->_flatlist->getNrOfEntries() ) ) {
+        WCFiletype *ft = ftw->_flatlist->getEntry( row ).filetype;
 	if ( ft != NULL ) {
 	  sets->_type = ft;
 	}
@@ -864,8 +864,8 @@ std::auto_ptr< StartProgOp::FiletypeWindow > StartProgOp::buildFTWindow( AWindow
   lv->setDisplayFocus( true );
   lv->setAcceptFocus( true );
 
-  std::vector<FlatTypeList::flattypelist_t> *l1 = wconfig->getFlatTypeList();
-  wconfig->buildLVFromFlat( lv, l1, NULL );
+  FlatTypeList *l1 = wconfig->getFlatTypeList();
+  l1->buildLV( lv, NULL );
 
   win->contMaximize( true );
   
@@ -875,8 +875,8 @@ std::auto_ptr< StartProgOp::FiletypeWindow > StartProgOp::buildFTWindow( AWindow
 }
 
 StartProgOp::FiletypeWindow::FiletypeWindow( FieldListView *lv,
-					     std::vector<FlatTypeList::flattypelist_t> *flatlist ) : _lv( lv ),
-												     _flatlist( flatlist )
+					     FlatTypeList *flatlist ) : _lv( lv ),
+                                                                        _flatlist( flatlist )
 {
 }
 
