@@ -1,6 +1,6 @@
 /* wcfiletype.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2006-2007 Ralf Hoffmann.
+ * Copyright (C) 2006-2008 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "wcfiletype.hh"
@@ -25,6 +25,7 @@
 #include "datei.h"
 #include "functionproto.h"
 #include "simplelist.hh"
+#include "stringmatcher_fnmatch.hh"
  
 WCFiletype::WCFiletype()
 {
@@ -62,6 +63,9 @@ WCFiletype::WCFiletype()
     colbg[i] = 0;
   }
   colext = NULL;
+
+  m_use_magic = false;
+  m_magic_pattern = "";
 }
 
 int WCFiletype::getinternID() const
@@ -161,6 +165,9 @@ WCFiletype *WCFiletype::duplicate() const
   tft->setCustomColor( 1, colbg );
   tft->setColorExt( colext );
 
+  tft->setUseMagic( m_use_magic );
+  tft->setMagicPattern( m_magic_pattern );
+
   return tft;
 }
 
@@ -828,6 +835,13 @@ bool WCFiletype::save(Datei *fh) const
   fh->configPutPairNum( "unselectactivecolor", colfg[2], colbg[2] );
   fh->configPutPairNum( "selectactivecolor", colfg[3], colbg[3] );
 
+  if ( m_magic_pattern.length() > 0 ) {
+      fh->configPutPairString( "magicpattern", m_magic_pattern.c_str() );
+  }
+  if ( m_use_magic == true ) {
+      fh->configPutPairBool( "usemagic", m_use_magic );
+  }
+
   return true;
 }
 
@@ -924,3 +938,40 @@ void WCFiletype::clearCustomActions()
     }
     customaction.clear();
 }
+
+std::string WCFiletype::getNameString() const
+{
+    return name;
+}
+
+bool WCFiletype::getUseMagic() const
+{
+    return m_use_magic;
+}
+
+void WCFiletype::setUseMagic( bool nv )
+{
+    m_use_magic = nv;
+}
+
+std::string WCFiletype::getMagicPattern() const
+{
+    return m_magic_pattern;
+}
+
+void WCFiletype::setMagicPattern( const std::string &pat )
+{
+    m_magic_pattern = pat;
+    m_magic_matcher = NULL;
+}
+
+bool WCFiletype::magicMatch( const std::string &match_string )
+{
+    if ( m_magic_matcher.getVal() == NULL ) {
+        //TODO also support regexs and case insensitive matches
+        m_magic_matcher = new StringMatcherFNMatch();
+        m_magic_matcher->setMatchString( m_magic_pattern );
+        m_magic_matcher->setMatchCaseSensitive( true );
+    }
+    return m_magic_matcher->match( match_string );
+}
