@@ -1,6 +1,6 @@
 /* wconfig_color.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2006 Ralf Hoffmann.
+ * Copyright (C) 2006-2008 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "wconfig_color.hh"
@@ -53,8 +53,11 @@ ColorPanel::ColorPanel( AWindow &basewin, WConfig &baseconfig ) : WConfigPanel(
   _tv_bg_b = NULL;
   _tv_hfg_b = NULL;
   _tv_hbg_b = NULL;
+  _tv_sel_fg_b = NULL;
+  _tv_sel_bg_b = NULL;
   _tv_cols_sb = NULL;
   _tv_high_sb = NULL;
+  _tv_sel_sb = NULL;
 }
 
 ColorPanel::~ColorPanel()
@@ -291,7 +294,7 @@ int ColorPanel::create()
 
   ac1->add( new BevelBox( _aguix, 0, 0, 10, 2, 0 ), 0, 11, AContainer::CINCW );
   
-  AContainer *ac1_7 = ac1->add( new AContainer( this, 3, 2 ), 0, 12 );
+  AContainer *ac1_7 = ac1->add( new AContainer( this, 3, 3 ), 0, 12 );
   ac1_7->setBorderWidth( 0 );
   ac1_7->setMinSpace( 5 );
   ac1_7->setMaxSpace( 5 );
@@ -320,6 +323,17 @@ int ColorPanel::create()
                                    2, 1, AContainer::CFIX );
   _tv_hbg_b->connect( this );
 
+  _tv_sel_sb = (SolidButton*)ac1_7->add( new SolidButton( _aguix, 0, 0, catalog.getLocale( 791 ),
+                                                          current_cols.getTextViewSelectionFG(),
+                                                          current_cols.getTextViewSelectionBG(), false ),
+                                         0, 2, AContainer::CINCW );
+  _tv_sel_fg_b = (Button*)ac1_7->add( new Button( _aguix, 0, 0, catalog.getLocale( 32 ), 1, 0, 0 ),
+                                      1, 2, AContainer::CFIX );
+  _tv_sel_fg_b->connect( this );
+  _tv_sel_bg_b = (Button*)ac1_7->add( new Button( _aguix, 0, 0, catalog.getLocale( 33 ), 1, 0, 0 ),
+                                      2, 2, AContainer::CFIX );
+ _tv_sel_bg_b->connect( this );
+
   contMaximize( true );
   return 0;
 }
@@ -361,6 +375,8 @@ int ColorPanel::saveValues()
   current_cols.setTextViewBackground( _tv_cols_sb->getBG() );
   current_cols.setTextViewHighlightedFG( _tv_high_sb->getFG() );
   current_cols.setTextViewHighlightedBG( _tv_high_sb->getBG() );
+  current_cols.setTextViewSelectionFG( _tv_sel_sb->getFG() );
+  current_cols.setTextViewSelectionBG( _tv_sel_sb->getBG() );
   _baseconfig.setColorDefs( current_cols );
   return 0;
 }
@@ -458,6 +474,16 @@ void ColorPanel::run( Widget *elem, AGMessage &msg )
         if ( col >= 0 ) {
             _tv_high_sb->setBG( col );
         }
+    } else if ( msg.button.button == _tv_sel_fg_b ) {
+        col = tempconfig->palette( _tv_sel_sb->getFG() );
+        if ( col >= 0 ) {
+            _tv_sel_sb->setFG( col );
+        }
+    } else if ( msg.button.button == _tv_sel_bg_b ) {
+        col = tempconfig->palette( _tv_sel_sb->getBG() );
+        if ( col >= 0 ) {
+            _tv_sel_sb->setBG( col );
+        }
     } else {
       for ( int i = 0; i < 10; i++ ) {
         if(msg.button.button==b[i][0]) {
