@@ -1,6 +1,6 @@
 /* worker.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2007 Ralf Hoffmann.
+ * Copyright (C) 2001-2008 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "worker.h"
@@ -53,6 +53,8 @@
 #include "workerversion.h"
 #include "nwc_path.hh"
 #include <iostream>
+#include <aguix/popupmenu.hh>
+#include "magic_db.hh"
 
 Requester *Worker::req_static=NULL;
 int Worker::argc = 0;
@@ -64,7 +66,7 @@ int Worker::workerInstances = 0;
 short usr1signal = 0;
 
 #ifdef HAVE_SIGACTION
-void worker_sighandler( int s )
+static void worker_sighandler( int s )
 {
   if ( s == SIGUSR1 ) {
     usr1signal = 1;
@@ -94,6 +96,7 @@ Worker::Worker(int targc,char **targv)
   listerwin[0] = NULL;
   listerwin[1] = NULL;
   maincont = NULL;
+  m_worker_menu = NULL;
   curRows = 0;
   curColumns = 0;
   w=600;
@@ -134,6 +137,8 @@ Worker::Worker(int targc,char **targv)
   
   lastkey = 0;
   lastmod = 0;
+  lastkey_time = 0;
+
   keyhashtable = NULL;
   keyhashtable_size = 1000;
   waitcursorcount = 0;
@@ -257,6 +262,11 @@ void Worker::run()
               shuffleButton( 1, true );              
             }
             handleSub=false;
+          } else if ( msg->button.button == statebar ) {
+              if ( msg->button.state == 2 ) {
+                  openWorkerMenu();
+              }
+              handleSub = false;
           } else {
             for(i=0;i<rows;i++) {
               if(pathbs[i]==msg->button.button) {
@@ -304,6 +314,12 @@ void Worker::run()
             handleSub = false;
 	  }
           break;
+        case AG_POPUPMENU_CLICKED:
+            if ( msg->popupmenu.menu == m_worker_menu ) {
+                startMenuAction( msg );
+                handleSub = false;
+            }
+            break;
         default:
           break;
       }
@@ -366,8 +382,10 @@ void Worker::run()
       lasttimep=0;
     }
   }
-  saveListerState();
-  wconfig->savesize(w,h);
+
+  if ( wconfig->getSaveWorkerStateOnExit() == true ) {
+      saveWorkerState();
+  }
   delete lister[0];
   delete lister[1];
 
@@ -450,11 +468,17 @@ int main(int argc,char **argv)
       _freesafe( setlang );
     }
     
+    MagicDB::getInstance().init();
+
     worker->run();
+    
+    MagicDB::getInstance().fini();
+    
     delete wconfig;
   } else {
     printf("Worker: Can't connect to X!\n");
   }
+
   delete worker;
   delete ugdb;
 
@@ -790,15 +814,19 @@ void Worker::setupMainWin()
     aboutb->setBG( 0, wconfig->getStatusbar(1) );
     configureb->setFG( 0, wconfig->getStatusbar(0) );
     configureb->setBG( 0, wconfig->getStatusbar(1) );
-    statebar->setFG( wconfig->getStatusbar(0) );
-    statebar->setBG( wconfig->getStatusbar(1) );
+    statebar->setFG( 0, wconfig->getStatusbar(0) );
+    statebar->setBG( 0, wconfig->getStatusbar(1) );
+    statebar->setFG( 1, wconfig->getStatusbar(0) );
+    statebar->setBG( 1, wconfig->getStatusbar(1) );
   } else {
     aboutb->setFG( 0, 2 );
     aboutb->setBG( 0, 4 );
     configureb->setFG( 0, 2 );
     configureb->setBG( 0, 4 );
-    statebar->setFG( 2 );
-    statebar->setBG( 4 );
+    statebar->setFG( 0, 2 );
+    statebar->setBG( 0, 4 );
+    statebar->setFG( 1, 2 );
+    statebar->setBG( 1, 4 );
   }
   clockbar->setFG( 0, wconfig->getClockbar(0) );
   clockbar->setBG( 0, wconfig->getClockbar(1) );
@@ -834,7 +862,7 @@ void Worker::setupMainWin()
 void Worker::setStatebarText(const char *str)
 {
   if ( statebar != NULL ) {
-    statebar->setText( str );
+    statebar->setText( 0, str );
     last_statebar_text[0] = last_statebar_text[1];
     last_statebar_text[1] = str;
   }
@@ -963,7 +991,7 @@ void Worker::about()
   int erg;
   
   tstr = (char*)_allocsafe( 1024 + 3 * A_BYTESFORNUMBER( int ) + strlen( WORKER_COMMENT ) );
-  sprintf(tstr,"Worker %d.%d.%d%s|Copyright (C) 1998 - 2007 Ralf Hoffmann",WORKER_MAJOR,WORKER_MINOR,WORKER_PATCH,WORKER_COMMENT);
+  sprintf(tstr,"Worker %d.%d.%d%s|Copyright (C) 1998 - 2008 Ralf Hoffmann",WORKER_MAJOR,WORKER_MINOR,WORKER_PATCH,WORKER_COMMENT);
   str1 = tstr;
   _freesafe( tstr );
   
@@ -1003,6 +1031,13 @@ void Worker::about()
       break;
   }
 #endif
+  str1 += "|File magic support: ";
+#ifdef HAVE_LIBMAGIC
+  str1 += "yes";
+#else
+  str1 += "no";
+#endif
+
 
 #ifdef USE_MEM_SYSTEM
   str1 += "|This program is compiled with SLOW memorysystem";
@@ -1038,7 +1073,7 @@ bool Worker::configure()
   std::string oldsbt;
   bool erg;
 
-  oldsbt = statebar->getText();
+  oldsbt = statebar->getText( 0 );
   setStatebarText( catalog.getLocale( 595 ) );
   setWaitCursor();
   erg = wconfig->configure();
@@ -1157,6 +1192,12 @@ int Worker::interpret(List* coms,ActionMessage *msg)
   return 0;
 }
 
+static bool isDoubleKeyTime( Time t2, Time t1 )
+{
+    if ( abs( (int)( t2 - t1 ) ) < ( 60 * 1000 ) ) return true;
+    return false;
+}
+
 int Worker::activateShortkey(AGMessage *msg)
 {
   int keystate;
@@ -1193,61 +1234,46 @@ int Worker::activateShortkey(AGMessage *msg)
      *       found: execute and clear previous
      *       not found: store key as previous
      */
-    if ( lastkey == 0 ) {
-      if ( findkey( msg->key.key, keystate, &b1, &hk1, &p1 ) > 0 ) {
-        if ( b1 != NULL ) {
-          amsg.mode = amsg.AM_MODE_NORMAL;
-          interpret( b1->getComs(), &amsg );
-          found = true;
-        } else if ( hk1 != NULL ) {
-          amsg.mode = amsg.AM_MODE_NORMAL;
-          interpret( hk1->getComs(), &amsg );
-          found = true;
-        } else if ( p1 != NULL ) {
-          setPath( p1 );
-          found = true;
+
+    if ( lastkey != 0 && isDoubleKeyTime( msg->key.time, lastkey_time ) == true ) {
+        if ( findkey( lastkey, lastmod, msg->key.key, keystate, &b1, &hk1, &p1 ) > 0 ) {
+            if ( b1 != NULL ) {
+                amsg.mode = amsg.AM_MODE_NORMAL;
+                interpret( b1->getComs(), &amsg );
+                found = true;
+            } else if ( hk1 != NULL ) {
+                amsg.mode = amsg.AM_MODE_NORMAL;
+                interpret( hk1->getComs(), &amsg );
+                found = true;
+            } else if ( p1 != NULL ) {
+                setPath( p1 );
+                found = true;
+            }
+            lastkey = 0;
+            lastmod = 0;
         }
-      } else {
-        lastkey = msg->key.key;
-        lastmod = keystate;
-      }
-    } else {
-      if ( findkey( lastkey, lastmod, msg->key.key, keystate, &b1, &hk1, &p1 ) > 0 ) {
-        if ( b1 != NULL ) {
-          amsg.mode = amsg.AM_MODE_NORMAL;
-          interpret( b1->getComs(), &amsg );
-          found = true;
-        } else if ( hk1 != NULL ) {
-          amsg.mode = amsg.AM_MODE_NORMAL;
-          interpret( hk1->getComs(), &amsg );
-          found = true;
-        } else if ( p1 != NULL ) {
-          setPath( p1 );
-          found = true;
-        }
-        lastkey = 0;
-        lastmod = 0;
-      } else {
+    }
+    if ( found == false ) {
         if ( findkey( msg->key.key, keystate, &b1, &hk1, &p1 ) > 0 ) {
-          if ( b1 != NULL ) {
-            amsg.mode = amsg.AM_MODE_NORMAL;
-            interpret( b1->getComs(), &amsg );
-            found = true;
-          } else if ( hk1 != NULL ) {
-            amsg.mode = amsg.AM_MODE_NORMAL;
-            interpret( hk1->getComs(), &amsg );
-            found = true;
-          } else if ( p1 != NULL ) {
-            setPath( p1 );
-            found = true;
-          }
-          lastkey = 0;
-          lastmod = 0;
+            if ( b1 != NULL ) {
+                amsg.mode = amsg.AM_MODE_NORMAL;
+                interpret( b1->getComs(), &amsg );
+                found = true;
+            } else if ( hk1 != NULL ) {
+                amsg.mode = amsg.AM_MODE_NORMAL;
+                interpret( hk1->getComs(), &amsg );
+                found = true;
+            } else if ( p1 != NULL ) {
+                setPath( p1 );
+                found = true;
+            }
+            lastkey = 0;
+            lastmod = 0;
         } else {
-          lastkey = msg->key.key;
-          lastmod = keystate;
+            lastkey = msg->key.key;
+            lastmod = keystate;
+            lastkey_time = msg->key.time;
         }
-      }
     }
     return ( found == true ) ? 1 : 0;
   }
@@ -2350,6 +2376,11 @@ void Worker::closeMainWin()
 {
   unsigned int i, j;
 
+  if ( m_worker_menu != NULL ) {
+      delete m_worker_menu;
+      m_worker_menu = NULL;
+  }
+
   delete req_static;
   req_static = new Requester( aguix );
 
@@ -2383,9 +2414,9 @@ void Worker::closeMainWin()
 
 void Worker::showLicense()
 {
-  AFontWidth lencalc( aguix, NULL );
-  TextStorageString ts( cgpl, lencalc );
-  req_static->request( catalog.getLocale( 509 ), ts, catalog.getLocale( 11 ) );
+    RefCount<AFontWidth> lencalc( new AFontWidth( aguix, NULL ) );
+    TextStorageString ts( cgpl, lencalc );
+    req_static->request( catalog.getLocale( 509 ), ts, catalog.getLocale( 11 ) );
 }
 
 void Worker::setWaitCursor()
@@ -2547,7 +2578,11 @@ void Worker::createMainWin()
   aboutb->resize(th,th);
   configureb=new Button(aguix,0,0,"C",1,0,2);
   configureb->setAcceptFocus( false );
-  statebar=new SolidButton(aguix,0,0,th,"",1,0,0);
+  statebar = new Button( aguix, 0, 0, th, "", "", 1, 1, 0, 0, 4 );
+  statebar->deactivate( 0 );
+  statebar->setShowDual( false );
+  statebar->setAcceptFocus( false );
+  statebar->setText( 1, catalog.getLocale( 786 ) );
   clockbar=new Button(aguix,0,0,th,"","",1,1,0,0,3);
   clockbar->setAcceptFocus( false );
   clockbar->setShowDual(false);
@@ -2567,6 +2602,8 @@ void Worker::createMainWin()
   delete req_static;
   req_static = new Requester( aguix, mainwin );
   aguix->setTransientWindow( mainwin );
+
+  createWorkerMenu();
 }
 
 AWindow *Worker::getListerWin( Lister *l )
@@ -2896,3 +2933,92 @@ std::string Worker::getWorkerConfigDir()
     }
     return d;
 }
+
+void Worker::createWorkerMenu()
+{
+    if ( m_worker_menu != NULL ) {
+        delete m_worker_menu;
+        m_worker_menu = NULL;
+    }
+
+    std::list<PopUpMenu::PopUpEntry> m1;
+    PopUpMenu::PopUpEntry e1;
+    e1.name = catalog.getLocale( 787 );
+    e1.type = PopUpMenu::HEADER;
+    m1.push_back( e1 );
+    e1.type = PopUpMenu::HLINE;
+    m1.push_back( e1 );
+
+    // about
+    e1.type = PopUpMenu::NORMAL;
+    e1.name = catalog.getLocale( 208 );
+    e1.id = 1;
+    m1.push_back( e1 );
+    
+    // configure
+    e1.type = PopUpMenu::NORMAL;
+    e1.name = catalog.getLocale( 0 );
+    e1.id = 2;
+    m1.push_back( e1 );
+    
+    e1.type = PopUpMenu::HLINE;
+    m1.push_back( e1 );
+
+    // save worker state
+    e1.type = PopUpMenu::NORMAL;
+    e1.name = catalog.getLocale( 788 );
+    e1.id = 3;
+    m1.push_back( e1 );
+    
+    e1.type = PopUpMenu::HLINE;
+    m1.push_back( e1 );
+
+    // quit
+    e1.type = PopUpMenu::NORMAL;
+    e1.name = catalog.getLocale( 789 );
+    e1.id = 4;
+    m1.push_back( e1 );
+    
+    m_worker_menu = new PopUpMenu( aguix, m1 );
+    m_worker_menu->create();
+}
+
+void Worker::openWorkerMenu()
+{
+    if ( m_worker_menu != NULL ) {
+        m_worker_menu->show();
+    }
+}
+
+void Worker::startMenuAction( AGMessage *msg )
+{
+    if ( msg->popupmenu.menu != m_worker_menu ) return;
+
+    switch ( msg->popupmenu.clicked_entry_id ) {
+        case 1: // about
+            about();
+            break;
+        case 2: // configure
+            configure();
+            break;
+        case 3: // save worker state
+            saveWorkerState();
+            break;
+        case 4: // quit worker
+            quit( 1 );
+            break;
+        default:
+            break;
+    }
+}
+
+void Worker::saveWorkerState()
+{
+    saveListerState();
+    wconfig->savesize( w, h);
+}
+
+int Worker::getStatebarWidth()
+{
+    return statebar->getWidth() - 2 * 2;
+}
