@@ -1,6 +1,6 @@
 /* worker_locale.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2007 Ralf Hoffmann.
+ * Copyright (C) 2001-2008 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "worker_locale.h"
@@ -24,8 +24,8 @@
 #include "worker.h"
 #include <aguix/utf8.hh>
 
-#define CATENTRY 780
-#define CATCOMENTRY 54
+#define CATENTRY 811
+#define CATCOMENTRY 55
 #define CATFLAGENTRY 59
 
 WorkerLocale catalog;
@@ -190,7 +190,7 @@ void WorkerLocale::initBuiltinLang()
   catalog[134]=dupstring( "Terminal program (with %s for file to execute in the terminal):" );
   catalog[135]=dupstring( "Overwrite all" );
   catalog[136]=dupstring( "Overwrite none" );
-  catalog[137]=dupstring( "| Target size: %s| Source size: %s|| Targe ttime: %s| Source time: %s" );
+  catalog[137]=dupstring( "| Target size: %s| Source size: %s|| Target time: %s| Source time: %s" );
   catalog[138]=dupstring( "Failed to remove the file %s|I will skip this file!" );
   catalog[139]=dupstring( "Failed to remove the destination file|The file %s is probably incomplete!" );
   catalog[140]=dupstring( "Creating database for deleting" );
@@ -708,12 +708,12 @@ the default colors would be: 1 0 2 1 1 7 2 7" );
   catalog[617]=dupstring( "Do not enter directory" );
   catalog[618]=dupstring( "Could not create temporary copy of %s!" );
   catalog[619]=dupstring( "Don't check content of virtual files" );
-  catalog[620]=dupstring( "Hostname:" );
-  catalog[621]=dupstring( "Username:" );
+  catalog[620]=dupstring( "Host name:" );
+  catalog[621]=dupstring( "User name:" );
   catalog[622]=dupstring( "Password:" );
   catalog[623]=dupstring( "Store password but don't open ftp connection" );
   catalog[624]=dupstring( "The password will be stored without encryption|in the worker configuration file!|Do really want to do this?" );
-  catalog[625]=dupstring( "No hostname or username was entered. Cannot continue!" );
+  catalog[625]=dupstring( "No host name or user name was entered. Cannot continue!" );
   catalog[626]=dupstring( "1 if entry is a local file, 0 for virtual file, -1 for non existing file or error" );
   catalog[627]=dupstring( "Store password even if password was already stored previously" );
   catalog[628]=dupstring( "The temporary copy of %s|has been changed but the original file will not be updated!" );
@@ -880,6 +880,37 @@ match any font." );
   catalog[777]=dupstring( "New action" );
   catalog[778]=dupstring( "Remove action" );
   catalog[779]=dupstring( "Enter name of the action to activate:" );
+  catalog[780]=dupstring( "ChMod mode:" );
+  catalog[781]=dupstring( "Set permission(s)" );
+  catalog[782]=dupstring( "Add permission(s)" );
+  catalog[783]=dupstring( "Remove permission(s)" );
+  catalog[784]=dupstring( "General settings" );
+  catalog[785]=dupstring( "Save Worker state on exit" );
+  catalog[786]=dupstring( "Open Worker menu" );
+  catalog[787]=dupstring( "Worker menu" );
+  catalog[788]=dupstring( "Save Worker state" );
+  catalog[789]=dupstring( "Quit Worker" );
+  catalog[790]=dupstring( "Search:" );
+  catalog[791]=dupstring( "Text view color for selection" );
+  catalog[792]=dupstring( "Same filesystem only" );
+  catalog[793]=dupstring( "Filter:" );
+  catalog[794]=dupstring( "Clear" );
+  catalog[795]=dupstring( "Libmagic pattern:" );
+  catalog[796]=dupstring( "Use libmagic pattern" );
+  catalog[797]=dupstring( "Test with file:" );
+  catalog[798]=dupstring( "Libmagic output:" );
+  catalog[799]=dupstring( "Output matches pattern:" );
+  catalog[800]=dupstring( "Check" );
+  catalog[801]=dupstring( "yes" );
+  catalog[802]=dupstring( "no" );
+  catalog[803]=dupstring( "Libmagic" );
+  catalog[804]=dupstring( "Worker can recognize the file type by using the libmagic database which comes|with the stand-alone program \"file\". You can enter a pattern with wildcards|to match the libmagic output. Use the test text field to check the libmagic|output and whether the pattern matches or not. Just enter the file name and|click on \"Check\"." );
+  catalog[805]=dupstring( "Edit bookmark" );
+  catalog[806]=dupstring( "Bookmark path:" );
+  catalog[807]=dupstring( "Bookmark alias:" );
+  catalog[808]=dupstring( "Use parent directory and activate entry" );
+  catalog[809]=dupstring( "Path" );
+  catalog[810]=dupstring( "Alias" );
 
 //  catalog[]=dupstring( "" );
   
@@ -937,6 +968,7 @@ match any font." );
   catalogcom[51]=dupstring( "Directory bookmarks" );
   catalogcom[52]=dupstring( "Open context menu" );
   catalogcom[53]=dupstring( "Run custom action" );
+  catalogcom[54]=dupstring( "Open Worker menu" );
   
   catalogflag[0]=dupstring( "Stringrequester" );
   catalogflag[1]=dupstring( "path" );
@@ -1106,16 +1138,25 @@ void WorkerLocale::parse(Datei *file,int cat)
   char *buffer=(char*)_allocsafe(128*1024);
   int mode,bufpos;
   int entrynr;
-  int ch;
+  char ch;
   char *tstr;
+  char filebuffer[1024];
+  int filebuffer_len = 0;
+  int filebuffer_offset = 0;
 
   mode=0;
   bufpos=0;
   entrynr=0;
   
   for(;;) {
-    ch=file->getCharAsInt();
-    if(ch==EOF) break;
+    if ( filebuffer_offset >= filebuffer_len ) {
+        filebuffer_len = file->read( filebuffer, 1024 );
+        filebuffer_offset = 0;
+    }
+    if ( filebuffer_offset >= filebuffer_len ) {
+        break;
+    }
+    ch = filebuffer[filebuffer_offset++];
     switch(mode) {
       case 1:
         if(ch=='\n') {
@@ -1131,7 +1172,7 @@ void WorkerLocale::parse(Datei *file,int cat)
           entrynr++;
           bufpos=0;
         } else {
-          buffer[w_min(128*1024-1,bufpos)]=(char)ch;
+          buffer[ w_min( 128 * 1024 - 1, bufpos ) ] = ch;
           bufpos++;
         }
         break;
@@ -1177,20 +1218,20 @@ void WorkerLocale::parse(Datei *file,int cat)
             entrynr=0;
           }
         } else {
-          buffer[w_min(128*1024-1,bufpos)]=(char)ch;
+          buffer[ w_min( 128 * 1024 - 1, bufpos ) ] = ch;
           bufpos++;
         }
         break;
       case 4:
         if(ch!='\n') {
-          buffer[w_min(128*1024-1,bufpos)]=(char)ch;
+          buffer[ w_min( 128 * 1024 - 1, bufpos ) ] = ch;
           bufpos++;
         }
         mode=3;
         break;
       default:
         if(isdigit(ch)!=0) {
-          buffer[w_min(128*1024-1,bufpos)]=(char)ch;
+          buffer[ w_min( 128 * 1024 - 1, bufpos ) ] = ch;
           bufpos++;
         } else if(ch=='#') {
           mode=1;
@@ -1206,7 +1247,7 @@ void WorkerLocale::parse(Datei *file,int cat)
           //TODO: bessere Meldung
           printf("oldstyle-catalog-format not supported\n");
           mode=2;
-          buffer[w_min(128*1024-1,bufpos)]=(char)ch;
+          buffer[ w_min( 128 * 1024 - 1, bufpos ) ] = ch;
           bufpos++;
           entrynr=0;
         }
